pub trait PointConcept<C: CoordinateConcept>: PointBase<C> {
    // Provided methods
    fn projected_distance(
        &self,
        other: &Self,
        orient: Orientation2D
    ) -> C::CoordinateDifference { ... }
    fn manhattan_distance(&self, other: &Self) -> C::CoordinateDifference { ... }
    fn distance_squared(&self, other: &Self) -> C::CoordinateDistance { ... }
    fn euclidian_distance(&self, other: &Self) -> C::CoordinateDistance { ... }
}
Concept of a point in the Euclidean plane.

Provided Methods

source

fn projected_distance( &self, other: &Self, orient: Orientation2D ) -> C::CoordinateDifference

Compute the x or y component of the vector from the point to the other point.

source

fn manhattan_distance(&self, other: &Self) -> C::CoordinateDifference

Compute the 1-norm of the vector pointing from the point to the other.

source

fn distance_squared(&self, other: &Self) -> C::CoordinateDistance

Squared euclidean distance.

source

fn euclidian_distance(&self, other: &Self) -> C::CoordinateDistance

Euclidean distance, i.e. 2-norm of the vector from the point to the other.

Implementors