Enum iron_shapes::isotropy::Orientation2D
source · pub enum Orientation2D {
Horizontal,
Vertical,
}Expand description
Orientation in two dimensions along one of the axes.
Variants
Implementations
sourceimpl Orientation2D
impl Orientation2D
sourcepub fn direction(self, d1: Direction1D) -> Direction2D
pub fn direction(self, d1: Direction1D) -> Direction2D
Get the positive or negative direction aligned with this orientation.
sourcepub fn is_vertical(&self) -> bool
pub fn is_vertical(&self) -> bool
Check if orientation is vertical.
sourcepub fn is_horizontal(&self) -> bool
pub fn is_horizontal(&self) -> bool
Check if orientation is horizontal.