pub struct MultiPolygon<T> {
    pub polygons: Vec<Polygon<T>>,
}
A MultiPolygon is a list of polygons. There is no restrictions on the polygons (they can be intersecting, empty, etc.).

Fields

polygons: Vec<Polygon<T>>

The list of polygons which defines the content of this multi polygon.

Implementations

source

impl<T> MultiPolygon<T>

source

pub fn new() -> Self

Create an empty set of polygons.

source

pub fn from_polygons(polygons: Vec<Polygon<T>>) -> Self

Create a MultiPolygon from a vector of Polygons.

source

pub fn len(&self) -> usize

Return the number of polygons.

source

pub fn is_empty(&self) -> bool

Check if polygon is empty.

source

pub fn insert(&mut self, polygon: Polygon<T>)

Insert a polygon into the region.

source

impl<T: Copy> MultiPolygon<T>

source

pub fn all_edges_iter(&self) -> impl Iterator<Item = Edge<T>> + '_

Iterate over all edges of the polygons including holes.