Enum iron_shapes::path::PathEndType
source · pub enum PathEndType<T> {
Flat,
Extended(T, T),
Round,
}Expand description
Encoding for the type of the beginning and end of the path.
Variants
Flat
Beginning and end of path are not extended.
Extended(T, T)
Define the extension length at the beginning and at the end of the path.
Round
Path ends are round (approximately semi-circles).