Struct iron_shapes::point::Point

source ·
pub struct Point<T> {
    location: Vector<T>,
}
A point is defined by a x and y coordinate in the euclidean plane.

Fields

location: Vector<T>

Store the location as a translation from the origin.

Implementations

source

impl<T> Point<T>

source

pub fn new(x: T, y: T) -> Self

Create a new point with x and y coordinates.

source

impl<T: Copy> Point<T>

source

pub fn v(&self) -> Vector<T>

Return the location of this point as a vector.

source

pub fn get(&self, coord: Orientation2D) -> T

Get a specific coordinate of the point.

source

pub fn set(&mut self, coord: Orientation2D, value: T)

Set a specific coordinate of the point.

source

impl<T: Zero> Point<T>

source

pub fn zero() -> Self

Get zero-Point.

Examples
use iron_shapes::point::Point;

let a = Point::zero();
let b = Point::new(0, 0);

assert_eq!(a, b);
source

pub fn is_zero(&self) -> bool

Check if this is the zero-Point.

Examples
use iron_shapes::point::*;

assert!(Point::<usize>::zero().is_zero());
source

impl<T: Copy + Mul<Output = T> + Add<Output = T> + Sub<Output = T>> Point<T>

source

pub fn distance_sq(self, other: &Point<T>) -> T

Compute the squared distance to the other point.

Examples
use iron_shapes::point::*;

let a = Point::new(0, 0);
let b = Point::new(2, 0);
assert_eq!(a.distance_sq(&b), 2*2);
source

pub fn cross_prod3(&self, b: Point<T>, c: Point<T>) -> T

Calculate the cross product of the two vectors defined by three points.

A positive value implies that selfab is counter-clockwise, negative implies clockwise.

(b - self) x (c - b)

Examples
use iron_shapes::point::Point;

let a = Point::new(1,0);
let b = Point::new(1,1);
let c = Point::new(0,1);

let p = a.cross_prod3(b, c);

assert_eq!(p, (b-a).cross_prod(c - b));
source

impl<T: Copy + Sub<Output = T> + NumCast> Point<T>

source

pub fn distance<F: Float>(self, other: &Point<T>) -> F

Compute the Euclidean distance betwen two points.

source

impl<T: Copy + NumCast> Point<T>

source

pub fn cast_to_float<F: Float + NumCast>(&self) -> Point<F>

Convert Point into a Point with floating point data type.

Methods from Deref<Target = Vector<T>>

source

pub fn norm1(&self) -> T

Get 1-norm of vector, i.e. the sum of the absolute values of its components.

Examples
use iron_shapes::vector::Vector;
let a = Vector::new(-2, 3);
assert_eq!(a.norm1(), 5);
source

pub fn orientation_of(&self, other: Self) -> Orientation

Check if other is oriented clockwise or counter-clockwise respective to self.

Examples
use iron_shapes::vector::Vector;
use iron_shapes::types::Orientation;

let a = Vector::new(1, 0);
let b = Vector::new(1, 1);
let c = Vector::new(1, -1);
let d = Vector::new(2, 0);

assert_eq!(a.orientation_of(b), Orientation::CounterClockWise);
assert_eq!(a.orientation_of(c), Orientation::ClockWise);
assert_eq!(a.orientation_of(d), Orientation::Straight);
source

pub fn norm2_squared(&self) -> T

Get squared 2-norm of vector.

Examples
use iron_shapes::vector::Vector;
let a = Vector::new(2, 3);
assert_eq!(a.norm2_squared(), 2*2+3*3);
source

pub fn dot(&self, other: Self) -> T

Calculate scalar product.

Examples
use iron_shapes::vector::Vector;

let a = Vector::new(1, 2);
let b = Vector::new(3, 4);

assert_eq!(a.dot(b), 1*3 + 2*4);
source

pub fn cross_prod(&self, other: Self) -> T

Calculate cross product.

Examples
use iron_shapes::vector::Vector;

let a = Vector::new(2, 0);
let b = Vector::new(0, 2);

assert_eq!(a.cross_prod(b), 4);
assert_eq!(b.cross_prod(a), -4);
source

pub fn cast_to_float<F: CoordinateType + Float + NumCast>(&self) -> Vector<F>

Convert vector into a vector with floating point data type.

source

pub fn norm2(&self) -> T

Get 2-norm of vector (length of vector).

Examples
use iron_shapes::vector::Vector;
let a = Vector::new(2.0, 3.0);
let norm2 = a.norm2();
let norm2_sq = norm2 * norm2;
let expected = a.norm2_squared();
assert!(norm2_sq < expected + 1e-12);
assert!(norm2_sq > expected - 1e-12);
source

pub fn normalized(&self) -> Self

Return a vector with the same direction but length 1.

Panics

Panics if the vector has length 0.

source

pub fn normal(&self) -> Self

Return the normal vector onto this vector. The normal has length 1.

Panics

Panics if the vector has length 0.

source

pub fn length<F: Float>(&self) -> F

Calculate length of vector.

Similar to Vector::norm2 but does potentially return another data type for the length.

Examples
use iron_shapes::vector::Vector;
let a = Vector::new(2.0, 3.0);
let length: f64 = a.length();
let norm2_sq = length * length;
let expected = a.norm2_squared();
assert!(norm2_sq < expected + 1e-12);
assert!(norm2_sq > expected - 1e-12);