Struct iron_shapes::simple_rpolygon::SimpleRPolygon
source · pub struct SimpleRPolygon<T> {
half_points: Vec<T>,
normalized: bool,
}Expand description
A SimpleRPolygon is a rectilinear polygon. It does not contain holes but can be self-intersecting.
The vertices are stored in an implicit format (one coordinate of two neighbour vertices is always the same
for rectilinear polygons). This reduces memory usage but has the drawback that edges must
alternate between horizontal and vertical. Vertices between two edges of the same orientation will
be dropped.
Fields
half_points: Vec<T>Vertices of the polygon. Begin with a y-coordinate. First edge is horizontal.
normalized: boolImplementations
sourceimpl<T> SimpleRPolygon<T>
impl<T> SimpleRPolygon<T>
sourcepub fn num_points(&self) -> usize
👎Deprecated: use len() instead
pub fn num_points(&self) -> usize
Get the number of vertices.
sourceimpl<T> SimpleRPolygon<T>
impl<T> SimpleRPolygon<T>
sourceimpl<T: Copy> SimpleRPolygon<T>
impl<T: Copy> SimpleRPolygon<T>
sourcepub fn edges(&self) -> impl Iterator<Item = REdge<T>> + '_
pub fn edges(&self) -> impl Iterator<Item = REdge<T>> + '_
Get all exterior edges of the polygon.
Examples
use iron_shapes::simple_rpolygon::SimpleRPolygon;
use iron_shapes::redge::REdge;
let coords = vec![(0, 0), (1, 0), (1, 1), (0, 1)];
let poly = SimpleRPolygon::try_new(&coords).unwrap();
let edges: Vec<_> = poly.edges().collect();
assert_eq!(edges, vec![
REdge::new((0, 0), (1, 0)),
REdge::new((1, 0), (1, 1)),
REdge::new((1, 1), (0, 1)),
REdge::new((0, 1), (0, 0)),
]);
sourceimpl<T: Copy + PartialEq> SimpleRPolygon<T>
impl<T: Copy + PartialEq> SimpleRPolygon<T>
sourcepub fn try_new<P>(points: &Vec<P>) -> Option<Self>where
P: Copy + Into<Point<T>>,
pub fn try_new<P>(points: &Vec<P>) -> Option<Self>where P: Copy + Into<Point<T>>,
Create new rectilinear polygon from points.
Returns None if the polygon defined by the points is not rectilinear.
use iron_shapes::simple_rpolygon::SimpleRPolygon;
let poly1 = SimpleRPolygon::try_new(&vec![(0, 0), (1, 0), (1, 1), (0, 1)]);
assert!(poly1.is_some());
// A triangle cannot be rectilinear.
let poly1 = SimpleRPolygon::try_new(&vec![(0, 0), (1, 0), (1, 1)]);
assert!(poly1.is_none());
sourceimpl<T: CoordinateType> SimpleRPolygon<T>
impl<T: CoordinateType> SimpleRPolygon<T>
sourcepub fn transformed(&self, tf: &SimpleTransform<T>) -> Self
pub fn transformed(&self, tf: &SimpleTransform<T>) -> Self
Apply the transformation to this rectilinear polygon.
sourcepub fn to_simple_polygon(&self) -> SimplePolygon<T>
pub fn to_simple_polygon(&self) -> SimplePolygon<T>
Convert to a SimplePolygon.
sourcepub fn convex_hull(&self) -> SimplePolygon<T>where
T: Ord,
pub fn convex_hull(&self) -> SimplePolygon<T>where T: Ord,
Get the convex hull of the polygon.
Implements Andrew’s Monotone Chain algorithm. See: http://geomalgorithms.com/a10-_hull-1.html
sourcepub fn lower_left_vertex(&self) -> Point<T>
pub fn lower_left_vertex(&self) -> Point<T>
Get the vertex with lowest x-coordinate. Prefer lower y-coordinates to break ties.
Examples
use iron_shapes::simple_rpolygon::SimpleRPolygon;
use iron_shapes::point::Point;
let coords = vec![(0, 0), (1, 0), (1, 1), (0, 1)];
let poly = SimpleRPolygon::try_new(&coords).unwrap();
assert_eq!(poly.lower_left_vertex(), Point::new(0, 0));
sourcefn lower_left_vertex_with_index(&self) -> (usize, Point<T>)
fn lower_left_vertex_with_index(&self) -> (usize, Point<T>)
Get the vertex with lowest x-coordinate and its index. Prefer lower y-coordinates to break ties.
sourcepub fn orientation(&self) -> Orientation
pub fn orientation(&self) -> Orientation
Get the orientation of the polygon, i.e. check if it is wound clock-wise or counter-clock-wise.
Examples
use iron_shapes::simple_rpolygon::SimpleRPolygon;
use iron_shapes::point::Point;
use iron_shapes::types::Orientation;
let coords = vec![(0, 0), (1, 0), (1, 1), (0, 1)];
let poly = SimpleRPolygon::try_new(&coords).unwrap();
assert_eq!(poly.orientation(), Orientation::CounterClockWise);
sourceimpl<T> SimpleRPolygon<T>where
T: Copy + PartialOrd,
impl<T> SimpleRPolygon<T>where T: Copy + PartialOrd,
sourceimpl<T: PartialOrd> SimpleRPolygon<T>
impl<T: PartialOrd> SimpleRPolygon<T>
sourcepub fn normalize(&mut self)
pub fn normalize(&mut self)
Rotate the vertices to get the lexicographically smallest polygon. Does not change the orientation.
sourcepub fn normalized(self) -> Self
pub fn normalized(self) -> Self
Rotate the vertices to get the lexicographically smallest polygon. Does not change the orientation.
sourceimpl<T: PartialEq> SimpleRPolygon<T>
impl<T: PartialEq> SimpleRPolygon<T>
sourcepub fn normalized_eq(&self, other: &Self) -> bool
pub fn normalized_eq(&self, other: &Self) -> bool
Equality test for simple polygons.
Two polygons are equal iff a cyclic shift on their vertices can be applied such that the both lists of vertices match exactly.