Struct iron_shapes::transform::ComplexTransform
source · pub struct ComplexTransform<T: CoordinateType> {
mirror: bool,
rotation: FloatType,
magnification: FloatType,
displacement: Vector<T>,
}Expand description
Transformation described by a mirroring at the x axis,
then a rotation around the origin, then a scaling, then a translation.
This transformation allows rotations by arbitrary angles.
Fields
mirror: boolMirror at x-axis?
rotation: FloatTypeRotation by an arbitrary angle (radians).
magnification: FloatTypeScaling.
displacement: Vector<T>Translation.