pub struct Matrix2dTransform<T: CoordinateType> {
    matrix: Matrix2d<T>,
}
Description of a transformation in the euclidean plane by a 2x2 matrix A. Transforming a point p is computed by the matrix product A*p.

Fields

matrix: Matrix2d<T>

Implementations

source

impl<T: CoordinateType> Matrix2dTransform<T>

source

pub fn new(matrix: Matrix2d<T>) -> Self

Create a new transform based on a matrix.

source

pub fn new_rotation90(angle: Angle) -> Self

Create a rotation by an integer multiple of 90 degrees.

source

pub fn new_scaling(factor: T) -> Self

Create a scaling by a factor.

source

pub fn new_mirror_x() -> Self

Mirror at the x-axis.

source

pub fn new_mirror_y() -> Self

Mirror at the y-axis.

source

pub fn transform_point(&self, p: Point<T>) -> Point<T>

Apply the transformation to a single point.

source

pub fn to_matrix2d(&self) -> Matrix2d<T>

Return the matrix describing this transformation.

source

pub fn try_invert(&self) -> Option<Self>

Get the inverse transformation.