Struct iron_shapes::transform::Matrix3dTransform
source · pub struct Matrix3dTransform<T: CoordinateType> {
pub m11: T,
pub m12: T,
pub m21: T,
pub m22: T,
pub m31: T,
pub m32: T,
}Expand description
Affine transformation represented as a 3x3 matrix like:
m11 m12 0
m21 m22 0
m31 m32 1
Fields
m11: Tm11
m12: Tm12
m21: Tm21
m22: Tm22
m31: Tm31. Used to express the x component of the translation.
m32: Tm32. Used to express the y component of the translation.
Implementations
sourceimpl<T: CoordinateType> Matrix3dTransform<T>
impl<T: CoordinateType> Matrix3dTransform<T>
sourcepub fn new(m11: T, m12: T, m21: T, m22: T, m31: T, m32: T) -> Self
pub fn new(m11: T, m12: T, m21: T, m22: T, m31: T, m32: T) -> Self
Create a new transform based on the matrix elements.
sourcepub fn transform_point(&self, p: Point<T>) -> Point<T>
pub fn transform_point(&self, p: Point<T>) -> Point<T>
Apply the transformation to a single point.
sourcepub fn to_matrix3d(&self) -> Matrix3d<T>
pub fn to_matrix3d(&self) -> Matrix3d<T>
Return the 3x3 matrix describing this transformation.
sourcepub fn to_matrix2d(&self) -> Matrix2d<T>
pub fn to_matrix2d(&self) -> Matrix2d<T>
Return the 2x2 matrix that describes this transformation without any translation.
sourcepub fn determinant(&self) -> T
pub fn determinant(&self) -> T
Compute the determinant of the 3x3 matrix that describes this transformation.
sourcepub fn try_invert(&self) -> Option<Self>
pub fn try_invert(&self) -> Option<Self>
Get the inverse transformation if it exists.
sourcepub fn then(&self, t: &Self) -> Self
pub fn then(&self, t: &Self) -> Self
Return a new transformation that is equal to applying
first self then t.
sourcepub fn then_scale(&self, factor: T) -> Self
pub fn then_scale(&self, factor: T) -> Self
Create a new transformation with an additional scaling.
sourcepub fn then_translate<V: Into<Vector<T>>>(&self, v: V) -> Self
pub fn then_translate<V: Into<Vector<T>>>(&self, v: V) -> Self
Create a new transformation with an additional translation.
sourcepub fn then_rotate90(&self, angle: Angle) -> Self
pub fn then_rotate90(&self, angle: Angle) -> Self
Create a new transformation with an additional rotation by a multiple of 90 degrees.
sourcepub fn then_mirror_x(&self) -> Self
pub fn then_mirror_x(&self) -> Self
Create a new transformation with an additional mirroring at the x-axis.
sourcepub fn then_mirror_y(&self) -> Self
pub fn then_mirror_y(&self) -> Self
Create a new transformation with an additional mirroring at the y-axis.
sourcepub fn get_translation(&self) -> Vector<T>
pub fn get_translation(&self) -> Vector<T>
Get the translation part of this affine transformation.
sourceimpl<T: CoordinateType + Float> Matrix3dTransform<T>
impl<T: CoordinateType + Float> Matrix3dTransform<T>
sourcepub fn then_rotate(&self, phi: T) -> Self
pub fn then_rotate(&self, phi: T) -> Self
Create a new transformation with an additional rotation.