pub enum Angle {
R0,
R90,
R180,
R270,
}
Angle expressed as a multiple of 90 degrees.
Describe the angle as a integer multiple of 90 degrees.
Convert an integer to an angle.
The integer specifies the number of 90 degree rotations.
The resulting type after applying the + operator.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Deserialize this value from the given Serde deserializer.
Read more
The resulting type after applying the - operator.
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Serialize this value into the given Serde serializer.
Read more
The resulting type after applying the - operator.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.