pub enum ContainsResult {
    No,
    OnBounds,
    WithinBounds,
}
This is a result type for containment checks.

  • No Not inside.
  • OnBounds Lies on the boundaries.
  • WithinBounds Fully inside.

Variants



No

Does not contain the point.



OnBounds

Contains the point but on the borders/end-points.



WithinBounds

Fully contains the point.

Implementations

source

impl ContainsResult

source

pub fn is_within_bounds(&self) -> bool

Tells if the point is contained but does not lie on the bounds.

source

pub fn inclusive_bounds(&self) -> bool

Tells if the point is contained or lies on the bounds.

source

pub fn on_bounds(&self) -> bool

Check if the point neither is on the bounds nor within the bounds.

source

pub fn is_no(&self) -> bool

Check if the point lies on the bounds.

source

pub fn max(self, other: Self) -> Self

Returns the stronger result of the both. Ordering from weak to strong is No, OnBounds, WithinBounds

source

pub fn min(self, other: Self) -> Self

Returns the weaker result of the both. Ordering from weak to strong is No, OnBounds, WithinBounds