Struct iron_shapes::multi_polygon::MultiPolygon
source · pub struct MultiPolygon<T> {
pub polygons: Vec<Polygon<T>>,
}Expand description
A MultiPolygon is a list of polygons. There is no restrictions on the polygons (they can be
intersecting, empty, etc.).
Fields
polygons: Vec<Polygon<T>>The list of polygons which defines the content of this multi polygon.
Implementations
sourceimpl<T> MultiPolygon<T>
impl<T> MultiPolygon<T>
sourcepub fn from_polygons(polygons: Vec<Polygon<T>>) -> Self
pub fn from_polygons(polygons: Vec<Polygon<T>>) -> Self
Create a MultiPolygon from a vector of Polygons.
sourceimpl<T: Copy> MultiPolygon<T>
impl<T: Copy> MultiPolygon<T>
sourcepub fn all_edges_iter(&self) -> impl Iterator<Item = Edge<T>> + '_
pub fn all_edges_iter(&self) -> impl Iterator<Item = Edge<T>> + '_
Iterate over all edges of the polygons including holes.