Struct iron_shapes::transform::Matrix2dTransform
source · pub struct Matrix2dTransform<T: CoordinateType> {
matrix: Matrix2d<T>,
}Expand description
Description of a transformation in the euclidean plane by a 2x2 matrix A.
Transforming a point p is computed by the matrix product A*p.
Fields
matrix: Matrix2d<T>Implementations
sourceimpl<T: CoordinateType> Matrix2dTransform<T>
impl<T: CoordinateType> Matrix2dTransform<T>
sourcepub fn new_rotation90(angle: Angle) -> Self
pub fn new_rotation90(angle: Angle) -> Self
Create a rotation by an integer multiple of 90 degrees.
sourcepub fn new_scaling(factor: T) -> Self
pub fn new_scaling(factor: T) -> Self
Create a scaling by a factor.
sourcepub fn new_mirror_x() -> Self
pub fn new_mirror_x() -> Self
Mirror at the x-axis.
sourcepub fn new_mirror_y() -> Self
pub fn new_mirror_y() -> Self
Mirror at the y-axis.
sourcepub fn transform_point(&self, p: Point<T>) -> Point<T>
pub fn transform_point(&self, p: Point<T>) -> Point<T>
Apply the transformation to a single point.
sourcepub fn to_matrix2d(&self) -> Matrix2d<T>
pub fn to_matrix2d(&self) -> Matrix2d<T>
Return the matrix describing this transformation.
sourcepub fn try_invert(&self) -> Option<Self>
pub fn try_invert(&self) -> Option<Self>
Get the inverse transformation.